==> moyoung_ble_plugin-1.0.61.tar.gz: example/lib/foregroundTaskHandler.dart <==
import 'dart:io';
import 'dart:isolate';

import 'package:flutter_foreground_task/flutter_foreground_task.dart';
import 'package:moyoung_ble_plugin/moyoung_ble.dart';

Future<void> requestForegroundServicePermissionsAndroid() async {
  if (!Platform.isAndroid) {
    return;
  }
  
  // To restart the service on device reboot or unexpected problem, you need to allow below permission.
  if (!await FlutterForegroundTask.isIgnoringBatteryOptimizations) {
    // This function requires `android.permission.REQUEST_IGNORE_BATTERY_OPTIMIZATIONS` permission.
    await FlutterForegroundTask.requestIgnoreBatteryOptimization();
  }

  // Android 13 and higher, you need to allow notification permission to expose foreground service notification.
  final NotificationPermission notificationPermissionStatus =
  await FlutterForegroundTask.checkNotificationPermission();
  if (notificationPermissionStatus != NotificationPermission.granted) {
    // This function requires `android.permission.POST_NOTIFICATIONS` permission.
    await FlutterForegroundTask.requestNotificationPermission();
  }
}

@pragma('vm:entry-point')
void ForegroundTaskCallback() {
  FlutterForegroundTask.setTaskHandler(ForegroundTaskHandler());
}

class ForegroundTaskHandler extends TaskHandler {

  @override
  Future<void> onDestroy(DateTime timestamp, SendPort? sendPort) {
    // TODO: implement onDestroy
    throw UnimplementedError();
  }

  //the below onEvent will be triggered based on the interval set in "WillStartForegroundTask"(main.dart)
  @override
  Future<void> onEvent(DateTime timestamp, SendPort? sendPort) async {
    print('ForegroundTaskHandler: onEvent');

  }

  @override
  Future<void> onStart(DateTime timestamp, SendPort? sendPort) async {
    print('ForegroundTaskHandler: onStart');
    MoYoungBle _blePlugin = MoYoungBle();
    bool isConnected = await _blePlugin.isConnected('DC:71:DD:50:00:8A');
    if (!isConnected) {
      _blePlugin.connect(ConnectBean(autoConnect: false, address: 'DC:71:DD:50:00:8A'));
    }
    print('ForegroundTaskHandler: $isConnected');
  }

}

==> moyoung_ble_plugin-1.0.62.tar.gz: example/lib/foregroundTaskHandler.dart <==
import 'dart:io';
import 'dart:isolate';

import 'package:flutter_foreground_task/flutter_foreground_task.dart';
import 'package:moyoung_ble_plugin/moyoung_ble.dart';

Future<void> requestForegroundServicePermissionsAndroid() async {
  if (!Platform.isAndroid) {
    return;
  }
  
  // To restart the service on device reboot or unexpected problem, you need to allow below permission.
  if (!await FlutterForegroundTask.isIgnoringBatteryOptimizations) {
    // This function requires `android.permission.REQUEST_IGNORE_BATTERY_OPTIMIZATIONS` permission.
    await FlutterForegroundTask.requestIgnoreBatteryOptimization();
  }

  // Android 13 and higher, you need to allow notification permission to expose foreground service notification.
  final NotificationPermission notificationPermissionStatus =
  await FlutterForegroundTask.checkNotificationPermission();
  if (notificationPermissionStatus != NotificationPermission.granted) {
    // This function requires `android.permission.POST_NOTIFICATIONS` permission.
    await FlutterForegroundTask.requestNotificationPermission();
  }
}

@pragma('vm:entry-point')
void ForegroundTaskCallback() {
  FlutterForegroundTask.setTaskHandler(ForegroundTaskHandler());
}

class ForegroundTaskHandler extends TaskHandler {

  @override
  Future<void> onDestroy(DateTime timestamp, SendPort? sendPort) {
    // TODO: implement onDestroy
    throw UnimplementedError();
  }

  //the below onEvent will be triggered based on the interval set in "WillStartForegroundTask"(main.dart)
  @override
  Future<void> onEvent(DateTime timestamp, SendPort? sendPort) async {
    print('ForegroundTaskHandler: onEvent');

  }

  @override
  Future<void> onStart(DateTime timestamp, SendPort? sendPort) async {
    print('ForegroundTaskHandler: onStart');
    MoYoungBle _blePlugin = MoYoungBle();
    bool isConnected = await _blePlugin.isConnected('DC:71:DD:50:00:8A');
    if (!isConnected) {
      _blePlugin.connect(ConnectBean(autoConnect: true, address: 'DC:71:DD:50:00:8A'));
    }
    print('ForegroundTaskHandler: $isConnected');
  }

}
